summaryrefslogtreecommitdiff
path: root/src/mongo/s/grid.h
diff options
context:
space:
mode:
authorSpencer T Brody <spencer@mongodb.com>2016-05-31 11:14:24 -0400
committerSpencer T Brody <spencer@mongodb.com>2016-06-13 18:26:51 -0400
commit7899a8e8a62548fb7a149649082bc34bbc001dc2 (patch)
tree537c418fcd35755518d2f359401ddc644c925454 /src/mongo/s/grid.h
parent710159c9602a6738e6455cfb26bc2d70a0454ae2 (diff)
downloadmongo-7899a8e8a62548fb7a149649082bc34bbc001dc2.tar.gz
SERVER-24323 Rename CatalogManager to ShardingCatalogClient
Renames the relevant classes and libraries, moves files, updates comments referencing the CatalogManager, and renames common methods for getting the catalogManager (like grid.catalogManager()). No functional changes.
Diffstat (limited to 'src/mongo/s/grid.h')
-rw-r--r--src/mongo/s/grid.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mongo/s/grid.h b/src/mongo/s/grid.h
index 02d5798d80d..4cc1cf71970 100644
--- a/src/mongo/s/grid.h
+++ b/src/mongo/s/grid.h
@@ -37,7 +37,7 @@ namespace mongo {
class BalancerConfiguration;
class CatalogCache;
-class CatalogManager;
+class ShardingCatalogClient;
class ClusterCursorManager;
class OperationContext;
class ShardRegistry;
@@ -68,7 +68,7 @@ public:
* NOTE: Unit-tests are allowed to call it more than once, provided they reset the object's
* state using clearForUnitTests.
*/
- void init(std::unique_ptr<CatalogManager> catalogManager,
+ void init(std::unique_ptr<ShardingCatalogClient> catalogClient,
std::unique_ptr<CatalogCache> catalogCache,
std::unique_ptr<ShardRegistry> shardRegistry,
std::unique_ptr<ClusterCursorManager> cursorManager,
@@ -91,11 +91,11 @@ public:
void setAllowLocalHost(bool allow);
/**
* Returns a pointer to a CatalogManager to use for accessing catalog data stored on the config
* servers.
*/
- CatalogManager* catalogManager(OperationContext* txn) {
- return _catalogManager.get();
+ ShardingCatalogClient* catalogClient(OperationContext* txn) {
+ return _catalogClient.get();
}
CatalogCache* catalogCache() const {
@@ -148,7 +148,7 @@ public:
void clearForUnitTests();
private:
- std::unique_ptr<CatalogManager> _catalogManager;
+ std::unique_ptr<ShardingCatalogClient> _catalogClient;
std::unique_ptr<CatalogCache> _catalogCache;
std::unique_ptr<ShardRegistry> _shardRegistry;
std::unique_ptr<ClusterCursorManager> _cursorManager;
@@ -91,11 +91,11 @@ public:
void setAllowLocalHost(bool allow);
/**
- * Returns a pointer to a CatalogManager to use for accessing catalog data stored on the config
- * servers.
+ * Returns a pointer to a ShardingCatalogClient to use for accessing catalog data stored on the
+ * config servers.
*/